@@ -2,7 +2,7 @@
 #'
 #' Function to identify observations with standardized residuals exceeding
 #' \code{rLimit}. If not provided \code{rLimit} is computed as
-#' \code{qnorm(1 - 0.5 / rDf)} where \code{rDf} are the residual degrees
+#' \code{qnorm(1 - 0.5 / rDf)} where \code{rDf} is the residual degrees
 #' of freedom for the model. This value is then restricted to the interval
 #' 2..4. Alternatively a custom limit may be provided.\cr
 #' If \code{verbose = TRUE} a summary is printed of outliers and observations
@@ -13,11 +13,11 @@
 #' @param STA An object of class \code{STA}.
 #' @param trials A character vector specifying the trials for which outliers
 #' should be identified. If \code{trials = NULL}, all trials are included.
-#' @param traits A character vector specifying the names of the traits for
-#' which outliers should be identified.
+#' @param traits A character vector specifying the traits for which outliers
+#' should be identified.
 #' @param what A character string indicating whether the outliers should be
 #' identified for the fitted model with genotype as fixed
-#' (\code{what = "fixed"})or genotype as random (\code{what = "random"}) factor.
+#' (\code{what = "fixed"}) or genotype as random (\code{what = "random"}) factor.
 #' If \code{STA} contains only one model this model is chosen automatically.
 #' @param rLimit A numerical value used for determining when a value is
 #' considered an outlier. All observations with standardized residuals
@@ -92,10 +92,8 @@ outlierSTA <- function(STA,
     detection <- TRUE
     whatExt <- ifelse(what == "fixed", "stdResF", "stdResR")
     whatExtDf <- ifelse(what == "fixed", "rDfF", "rDfR")
-    stdRes <- extract(STA, trials = trial, traits = traitsTr,
-                      what = whatExt)[[trial]][[whatExt]]
-    rDf <- extract(STA, trials = trial, traits = traitsTr,
-                   what = whatExtDf)[[trial]][[whatExtDf]]
+    stdRes <- extractSTA(STA, trials = trial, traits = traitsTr, what = whatExt)
+    rDf <- extractSTA(STA, trials = trial, traits = traitsTr, what = whatExtDf)
     ## Create empty data.frame for storing results.
     outTr <- indicatorTr <- setNames(vector(mode = "list",
                                             length = length(traitsTr)),
@@ -104,7 +102,8 @@ outlierSTA <- function(STA,
       stdResTr <- stdRes
       ## Compute limit value for residuals.
       if (is.null(rLimit)) {
-        rLimit <- min(max(2, qnorm(p = 1 - 0.5 / rDf[trait])), 4)
+        rLimit <- min(max(2, qnorm(p = 1 - 0.5 /
+                                     rDf[rDf[["trial"]] == trial, trait])), 4)
       }
       datTr <- STA[[trial]]$TD[[trial]]
       ## Compute outliers.
