@@ -45,6 +45,11 @@ summary(wheatTD, trial = "SR_FI_11", traits = "GY")
 ## Create a summary for the two replicates in SR_FI_11.
 summary(wheatTD, trial = "SR_FI_11", traits = "GY", groupBy = "repId")
 
+## ----colorOpts, eval=FALSE----------------------------------------------------
+#  ## Set default colors for genotypes and trials.
+#  options("statgen.genoColors" = c("blue", "green", "yellow"))
+#  options("statgen.trialColors" = c("red", "brown", "purple"))
+
 ## ----layoutPlot---------------------------------------------------------------
 plot(wheatTD, trials = "SR_FI_11")
 
@@ -72,7 +77,7 @@ plot(wheatTD, plotType = "box", traits = "GY")
 ## Create a boxplot for grain yield with boxes grouped by year and repIds within
 ## years colored.
 plot(wheatTD, plotType = "box", traits = "GY", groupBy = "year", 
-     colorBy = "repId", orderBy = "descending")
+     colorTrialBy = "repId", orderBy = "descending")
 
 ## ----corPlot------------------------------------------------------------------
 ## Create a correlation plot for grain yield.
@@ -84,7 +89,7 @@ plot(wheatTD, plotType = "cor", traits = "GY")
 plot(wheatTD, plotType = "scatter", traits = "GY", addCorr = "tl")
 
 ## ----fitSp, message=FALSE-----------------------------------------------------
-## Fit a single trial model using a model based on a residual row column design.
+## Fit a single trial model using a model based on a resovable row column design.
 modWheatSp <- fitTD(TD = wheatTD, trials = "SR_FI_11", traits = "GY", design = "res.rowcol")
 
 ## ----fitSpSm, message=FALSE---------------------------------------------------
@@ -153,18 +158,18 @@ knitr::kable(optsTab, align = c("llll"), row.names = FALSE)
 
 ## ----extBLUEs-----------------------------------------------------------------
 ## Extract BLUEs
-BLUEsWheat <- extract(STA = modWheatSp, what = "BLUEs")
+BLUEsWheat <- extractSTA(STA = modWheatSp, what = "BLUEs")
 ## Extract BLUEs and BLUPs
-predWheat <- extract(STA = modWheatSp, what = c("BLUEs", "BLUPs"))
+predWheat <- extractSTA(STA = modWheatSp, what = c("BLUEs", "BLUPs"))
 
 ## ----extBLUEsKeep-------------------------------------------------------------
 ## Extract BLUEs from the fitted model.
-BLUEsWheat2 <- extract(STA = modWheatSp, what = "BLUEs", keep = "trial")
+BLUEsWheat2 <- extractSTA(STA = modWheatSp, what = "BLUEs", keep = "trial")
 head(BLUEsWheat2[["SR_FI_11"]]$BLUEs)
 
 ## ----extFit-------------------------------------------------------------------
 ## Extract fitted values from the model.
-fitVals <- extract(STA = modWheatSp, what = "fitted", keep = c("trial", "repId"))
+fitVals <- extractSTA(STA = modWheatSp, what = "fitted", keep = c("trial", "repId"))
 head(fitVals[["SR_FI_11"]]$fitted)
 
 ## ----STAtoTD, message=FALSE---------------------------------------------------
