@@ -68,6 +68,11 @@ test_that("option highlight overrides colorSubBlock in TD layout plot", {
                   c("~highlight.", "~color."))
 })
 
+test_that("option title overrides default title in TD layout plot", {
+  p1 <- plot(testTD, plotType = "layout", title = "test")
+  expect_equal(p1$E1$labels$title, "test")
+})
+
 ### TD map plot.
 
 test_that("TD map plot gives correct output types", {
@@ -95,7 +100,19 @@ test_that("option colorTrialBy functions properly for TD map plot", {
                "colorTrialBy should be a column in TD")
   expect_error(plot(TDHeat05, plotType = "map", colorTrialBy = "Plot"),
                "colorTrialBy should be unique within each trial")
-  expect_silent(plot(TDHeat05, plotType = "map", colorTrialBy = "trial"))
+  expect_error(plot(TDHeat05, plotType = "map", colorTrialBy = "trial",
+                    colTrial = c("orange", "red")),
+               "Number of colors provided doesn't match number of trial groups")
+  expect_silent(p1 <- plot(TDHeat05, plotType = "map", colorTrialBy = "trial"))
+  expect_silent(p2 <- plot(TDHeat05, plotType = "map", colorTrialBy = "trial",
+                           colTrial = "orange"))
+  expect_equal(p1$plot_env$colTrial, "red")
+  expect_equal(p2$plot_env$colTrial, "orange")
+})
+
+test_that("option title overrides default title in TD map plot", {
+  p1 <- plot(TDHeat05, plotType = "map", title = "test")
+  expect_equal(p1$labels$title, "test")
 })
 
 ### TD box plot.
@@ -127,6 +144,9 @@ test_that("option colorTrialBy functions properly for TD box plot", {
   expect_error(plot(testTD, plotType = "box", traits = "t1",
                     colorTrialBy = "grp"),
                "colorTrialBy should be a column in TD")
+  expect_error(plot(testTD, plotType = "box", traits = "t1",
+                    colorTrialBy = "repId", colTrial = "red"),
+               "Number of colors provided doesn't match number of trial groups")
   p <- plot(testTD, plotType = "box", traits = "t1", colorTrialBy = "repId",
             output = FALSE)
   expect_true(all(c("~repId", "~trial") %in% as.character(p$t1$mapping)))
@@ -145,6 +165,11 @@ test_that("option orderBy functions properly for TD box plot", {
                "levNw")
 })
 
+test_that("option title overrides default title in TD box plot", {
+  p1 <- plot(testTD, plotType = "box", traits = "t1", title = "test")
+  expect_equal(p1$t1$labels$title, "test")
+})
+
 ### TD correlation plot.
 
 test_that("TD correlation plot gives correct output types", {
@@ -173,6 +198,11 @@ test_that("TD correlation plot gives correct output types", {
                           output = FALSE))
 })
 
+test_that("option title overrides default title in TD correlation plot", {
+  p1 <- plot(TDMaize, plotType = "cor", traits = "yld", title = "test")
+  expect_equal(p1$yld$labels$title, "test")
+})
+
 ### TD scatter plot.
 
 test_that("TD scatter plot gives correct output types", {
@@ -198,12 +228,15 @@ test_that("option colorGenoBy functions properly for TD scatter plot", {
 })
 
 test_that("option colorTrialBy functions properly for TD scatter plot", {
-  expect_error(plot(TDMaize, plotType = "scatter", traits = "t1",
+  expect_error(plot(TDMaize, plotType = "scatter", traits = "yld",
                     colorTrialBy = 1),
                "colorTrialBy should be a character string")
-  expect_error(plot(TDMaize, plotType = "scatter", traits = "t1",
+  expect_error(plot(TDMaize, plotType = "scatter", traits = "yld",
                     colorTrialBy = "grp"),
                "colorTrialBy should be a column in TD")
+  expect_error(plot(TDMaize, plotType = "scatter", traits = "yld",
+                    colorTrialBy = "trial", colTrial = "red"),
+               "Number of colors provided doesn't match number of trial groups")
   expect_silent(plot(TDMaize, plotType = "scatter", traits = "yld",
                      colorTrialBy = "trial"))
 })
@@ -238,3 +271,9 @@ test_that("scatterPlot works correctly for trials with non-syntactic names", {
   names(TDMaize2)[1] <- "HN-96b"
   expect_silent(plot(TDMaize2, plotType = "scatter", traits = "yld"))
 })
+
+test_that("option title overrides default title in TD scatter plot", {
+  p1 <- plot(TDMaize, plotType = "scatter", traits = "yld", title = "test")
+  titleGrob <- which(p1$yld$layout$name == "title")
+  expect_equal(p1$yld$grobs[[titleGrob]]$children[[1]]$label, "test")
+})
